@@ -2,11 +2,11 @@ package Alien::FFI;
 
 use strict;
 use warnings;
-use 5.010;
+use 5.008001;
 use Carp qw( croak );
 
 # ABSTRACT: Get libffi compiler and linker flags
-our $VERSION = '0.11'; # VERSION
+our $VERSION = '0.12'; # VERSION
 
 
 sub new
@@ -26,10 +26,10 @@ sub install_type
   'system';
 }
 
+my $cflags;
+
 sub cflags
 {
-  state $cflags;
-  
   unless(defined $cflags)
   {
     $cflags = `$pkg_config --cflags libffi`;
@@ -40,10 +40,10 @@ sub cflags
   $cflags;
 }
 
+my $libs;
+
 sub libs
 {
-  state $libs;
-  
   unless(defined $libs)
   {
     $libs = `$pkg_config --libs libffi`;
@@ -73,7 +73,7 @@ Alien::FFI - Get libffi compiler and linker flags
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
